Index: components/test_runner/test_runner.h |
diff --git a/components/test_runner/test_runner.h b/components/test_runner/test_runner.h |
index b8f6284c647c9fc115f4e31938a89e6d1ab6f870..4ea4adeddf2910efe9977fae780411372bbd5736 100644 |
--- a/components/test_runner/test_runner.h |
+++ b/components/test_runner/test_runner.h |
@@ -529,8 +529,9 @@ class TestRunner : public WebTestRunner, |
// the test program on how to proceed. |
void SetBluetoothManualChooser(); |
- // Returns the events recorded since the last call to this function. |
- std::vector<std::string> GetBluetoothManualChooserEvents(); |
+ // Calls |callback| with a DOMString[] representing the events recorded since |
+ // the last call to this function. |
+ void GetBluetoothManualChooserEvents(v8::Local<v8::Function> callback); |
// Calls the BluetoothChooser::EventHandler with the arguments here. Valid |
// event strings are: |
@@ -623,6 +624,9 @@ class TestRunner : public WebTestRunner, |
const SkBitmap& snapshot); |
void DispatchBeforeInstallPromptCallback(scoped_ptr<InvokeCallbackTask> task, |
bool canceled); |
+ void GetBluetoothManualChooserEventsCallback( |
+ scoped_ptr<InvokeCallbackTask> task, |
+ const std::vector<std::string>& events); |
void CheckResponseMimeType(); |
void CompleteNotifyDone(); |